OC.L10N.register(
    "federation",
    {
    "Server added to the list of trusted ownClouds" : "Server aggiunto all'elenco di ownCloud affidabili",
    "Server is already in the list of trusted servers." : "Il server è già nell'elenco dei server affidabili.",
    "No ownCloud server found" : "Nessun server ownCloud trovato",
    "Could not add server" : "Impossibile aggiungere il server",
    "Federation" : "Federazione",
    "ownCloud Federation allows you to connect with other trusted ownClouds to exchange the user directory. For example this will be used to auto-complete external users for federated sharing." : "La federazione di ownCloud ti consente di collegarti con altri ownCloud di fiducia per scambiare la cartella degli utenti. Ad esempio, sarà utilizzata per il completamento automatico degli utenti esterni per la condivisione federata.",
    "Add server automatically once a federated share was created successfully" : "Aggiungi automaticamente il server dopo che una condivisione federata è stata creata con successo",
    "Trusted ownCloud Servers" : "Server ownCloud di fiducia",
    "+ Add ownCloud server" : "+ Aggiungi server ownCloud",
    "ownCloud Server" : "Server ownCloud"
},
"nplurals=2; plural=(n != 1);");
